@@ -206,7 +206,8 @@ bool ArgumentReader::read(ArgumentVector &args)
     // iterate through all argument denotations; loop might exit earlier when an denotation is unknown
     while (argv != end) {
         // check whether there are still values to read
-        if (values && lastArgInLevel->requiredValueCount() != Argument::varValueCount && values->size() < lastArgInLevel->requiredValueCount()) {
+        if (values && ((lastArgInLevel->requiredValueCount() != Argument::varValueCount) || (lastArgInLevel->flags() & Argument::Flags::Greedy))
+            && values->size() < lastArgInLevel->requiredValueCount()) {
             // read arg as value and continue with next arg
             values->emplace_back(argDenotation ? argDenotation : *argv);
             ++index;
@@ -468,7 +469,7 @@ inline bool notEmpty(const char *str)
  * Instances of the Argument class are used as definition when parsing command line
  * arguments. Arguments can be assigned to an ArgumentParser using
  * ArgumentParser::setMainArguments() and to another Argument instance using
- * Argument::setSecondaryArguments().
+ * Argument::setSubArguments().
  */
 
 /*!
@@ -628,7 +629,7 @@ Argument *firstPresentUncombinableArg(const ArgumentVector &args, const Argument
  *
  * \sa secondaryArguments()
  * \sa addSecondaryArgument()
- * \sa hasSecondaryArguments()
+ * \sa hasSubArguments()
  */
 void Argument::setSubArguments(const ArgumentInitializerList &secondaryArguments)
 {
@@ -651,8 +652,8 @@ void Argument::setSubArguments(const ArgumentInitializerList &secondaryArguments
  * \brief Adds \a arg as a secondary argument for this argument.
  *
  * \sa secondaryArguments()
- * \sa setSecondaryArguments()
- * \sa hasSecondaryArguments()
+ * \sa setSubArguments()
+ * \sa hasSubArguments()
  */
 void Argument::addSubArgument(Argument *arg)
 {
@@ -941,7 +942,7 @@ void ArgumentParser::parseArgs(int argc, const char *const *argv, ParseArgumentB
         if (behavior & ParseArgumentBehavior::ExitOnFailure) {
             CMD_UTILS_START_CONSOLE;
             cerr << failure;
-            invokeExit(1);
+            invokeExit(EXIT_FAILURE);
         }
         throw;
     }
@@ -1016,7 +1017,7 @@ void ArgumentParser::readArgs(int argc, const char *const *argv)
     // print Bash completion and prevent the application to continue with the regular execution
     if (completionMode) {
         printBashCompletion(argc, argv, currentWordIndex, reader);
-        invokeExit(0);
+        invokeExit(EXIT_SUCCESS);
     }
 }
 
@@ -1092,7 +1093,7 @@ void ArgumentParser::verifyArgs(const ArgumentVector &args)
         assert(!arg->abbreviation() || find(abbreviations.cbegin(), abbreviations.cend(), arg->abbreviation()) == abbreviations.cend());
         abbreviations.push_back(arg->abbreviation());
         assert(!arg->name() || find_if(names.cbegin(), names.cend(), [arg](const char *name) { return !strcmp(arg->name(), name); }) == names.cend());
-        assert(arg->requiredValueCount() == 0 || arg->subArguments().size() == 0);
+        assert(arg->requiredValueCount() == 0 || arg->subArguments().size() == 0 || (arg->flags() & Argument::Flags::Greedy));
         names.emplace_back(arg->name());
     }
     for (const Argument *arg : args) {
